@@ -1,6 +1,5 @@
-"""NDG Security Policy Information Point type definition
+"""NDG XACML Policy Information Point type definition
 
-NERC DataGrid
 """
 __author__ = "P J Kershaw"
 __date__ = "25/02/10"
@@ -8,4 +7,4 @@ __copyright__ = "(C) 2010 Science and Technology Facilities Council"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
 __license__ = "BSD - see LICENSE file in top-level directory"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = "$Id: pip.py 7087 2010-06-25 11:23:09Z pjkersha $"
+__revision__ = "$Id: pip.py 7256 2010-07-29 20:29:29Z pjkersha $"
