@@ -8,7 +8,7 @@ __copyright__ = "(C) 2010 Science and Technology Facilities Council"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
 __license__ = "BSD - see LICENSE file in top-level directory"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = "$Id: __init__.py 7109 2010-06-28 12:54:57Z pjkersha $"
+__revision__ = "$Id: __init__.py 7351 2010-08-20 14:46:35Z pjkersha $"
 from abc import ABCMeta, abstractmethod
 from datetime import datetime, timedelta
 import traceback
@@ -277,7 +277,42 @@ class XacmlFunctionNames(object):
 'urn:oasis:names:tc:xacml:1.0:function:rfc822Name-set-equals',
     )
 
+from ndg.xacml import XacmlError
 
+
+class UnsupportedFunctionError(XacmlError):
+    """Encountered a function type that is not recognised as part of the XACML
+    specification and is not supported in this implementation"""
+
+ 
+class UnsupportedStdFunctionError(UnsupportedFunctionError): 
+    """Encountered a function type that is not supported even though it is
+    part of the XACML specification"""
+    
+    
+def unsupportedFunctionErrorFactory(identifier, msg=None):
+    """Factory function to return an unsupported function exception based on
+    the function identifier passed in
+    
+    @param identifier: XACML function namespace to check
+    @type identifier: basestring
+    
+    @return: unsupported function exception instance
+    @rtype: UnsupportedFunctionError or UnsupportedStdFunctionError depending
+    on the identifier passed
+    """
+    if identifier in XacmlFunctionNames.FUNCTION_NAMES:
+        if msg is None:
+            msg = "%s: %s" % (UnsupportedStdFunctionError.__doc__, identifier)
+            
+        raise UnsupportedStdFunctionError(msg)
+    else:
+        if msg is None:
+            msg = "%s: %s" % (UnsupportedFunctionError.__doc__, identifier)
+            
+        raise UnsupportedFunctionError(msg)
+    
+    
 class FunctionClassFactoryInterface(object):
     """Interface class for function module class factory class
     """
@@ -442,8 +477,8 @@ class FunctionClassFactoryBase(FunctionClassFactoryInterface):
         self.__map[identifier] = functionClass
             
     def __call__(self, identifier):
-        """Return the class for the given XACML *-at-least-one-member-of type
-        function identifier
+        """Return the class for the given XACML type function identifier
+        
         @param identifier: XACML *-at-least-one-member-of type function
         identifier
         @type identifier: basestring
@@ -621,7 +656,11 @@ class FunctionMap(VettedDict):
             # No implementation exists - default to Abstract function
             self[functionNs] = NotImplemented
         else:
-            self[functionNs] = functionFactory(functionNs)
+            function = functionFactory(functionNs)
+            if function is None:
+                raise unsupportedFunctionErrorFactory(functionNs)
+                
+            self[functionNs] = function
             self.__classFactoryMap[functionNs] = functionFactory
                        
     def __getitem__(self, key):
