@@ -8,7 +8,7 @@ __copyright__ = "(C) 2010 Science and Technology Facilities Council"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
 __license__ = "BSD - see LICENSE file in top-level directory"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = "$Id: policy.py 7109 2010-06-28 12:54:57Z pjkersha $"
+__revision__ = "$Id: policy.py 7351 2010-08-20 14:46:35Z pjkersha $"
 import traceback
 import logging
 log = logging.getLogger(__name__)
@@ -22,8 +22,8 @@ from ndg.xacml.core.rule import Rule
 from ndg.xacml.core.obligation import Obligation
 from ndg.xacml.core.rule_combining_alg import (RuleCombiningAlgClassFactory,
                                                RuleCombiningAlgInterface)
-from ndg.xacml.core.exceptions import (UnsupportedStdFunctionError,
-                                       UnsupportedFunctionError)
+from ndg.xacml.core.functions import (UnsupportedStdFunctionError,
+                                      UnsupportedFunctionError)
 
 # Evaluation of a request context
 from ndg.xacml.core.context.response import Response
